import java.util.*;

/**
 * Klasse zur Speicherung eines einzelnen Artikelobjektes
 *
 * @author Bernhard Fiser 0109815
 * @version 1.1
 */
public class Artikel
{
	private String	desc;
	private Art	art;
	private int	artn;

	/**
	 * Constructor
	 * Legt ein neues Objekt an und initialisiert die internen
	 * privaten Variablen.
	 * @param Art : initielles Artobjekt.
	 */
	public Artikel(Art art)
	{
		this.art = art;
		this.desc = "";
		this.artn = 0;
	}

	/** Liefert die ID des Artikels zurck */
	public String getID()
	{
		if (this.art == null)
			return(null);
		return(this.art.getID() + this.artn);
	}

	/** Liefert numerischen Teil der ID des Artikels zurck */
	public int getIDn()
	{
		return(this.artn);
	}

	/** liefert die Art zurck
	  * @return Art art : Art */
	public Art getArt()
	{
		return(this.art);
	}

	/** liefert die Beschreibung des Artikels zurck
	 * @return String desc : Beschreibung */
	public String getDescription()
	{
		return(this.desc);
	}

	/** Parsed string und belegt die internen Instanzvariablen
	  * @param String :   String der Parameter enthlt
	  * @param HashMap :  HashMap der Art-Objekte
	  * @return boolean : true ... alles OK
	  * @return boolean : false .. Syntax error
	  */
	public boolean parseLine(String s, HashMap h)
	{
		String		t,
				a = "",
				b = "";
		StringTokenizer	st;
		int		i;

		/* Stringtokenizer initialisieren */
		i = 0;
		st = new StringTokenizer(s, ";");
		while (st.hasMoreTokens())
		{
			/* Token lesen */
			t = st.nextToken();
			switch (i)
			{
				/* ersten Token in Variable bernehmen */
				case 0 :
					b = t;
					break;

				/* Zweiten Token in Beschreibung des Artikels bernehmen */
				case 1 :
					this.desc = t;
					break;

				/* Dritten Token in numerische ID-Variable bernehmen */
				case 2 :
					/* Falls strlen weniger als 3 -> Syntaxerror */
					if (t.length() < 3)
						return(false);
					/* Numerischen Anteil in int konvertieren */
					a = t.substring(0, 2);
					try
					{
						this.artn = Integer.parseInt(t.substring(2));
					}
					/* Falls Konvertierung nicht mglich -> Syntaxerror */
					catch (Exception e)
					{
						return(false);
					}
					break;

				/* Weitere Tokens -> Syntaxerror */
				default :
					return(false);
			}
			/* Tokenzhler erhhen */
			i++;
		}
		/* Falls weniger als 3 Tokens -> Syntaxerror */
		if (i < 3)
			return(false);

		/* Falls Art nicht in HashMap gefunden -> Syntaxerror */
		if ((this.art = (Art) h.get(a.toLowerCase())) == null)
			return(false);

		/* Falls Beschreibung der Art nicht zu erstem Token passt -> Syntaxerror */
		if (b.compareToIgnoreCase(this.art.getDescription()) != 0)
			return(false);

		/* Andernfalls alles OK */
		return(true);
	}
}

